DropdownHeader class

Inheritance

Constructors

const

Properties

activeIndex → int?
选中查询内容是否显示选中颜色
final
controller → DropdownMenuController?
finalinherited
final
未选中图标
final
getItemLabel → GetItemLabel
头部显示内容
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
自定义头部图标 筛选头部高度
final
imageWidget → GetCustomizeImage?
只显示不回填值
final
isSideline → bool
是否有边线
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap → DropdownMenuHeadTapCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectColor → Color?
final
selectIsChangingColor → bool
final
specialModules → List<int>
选中图标
final
titles → List
final
unselectedColor → Color?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → DropdownState<DropdownWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited