CustomInputClass class

Constructors

CustomInputClass({String startInput = 'startInput', String endInput = 'endInput', String startHintText = '', String endHintText = '', TextInputType? keyboardType})
输入格式
const

Properties

endHintText → String
开始展示提示
final
endInput → String
开始输入内容
final
hashCode → int
The hash code for this object.
no setterinherited
keyboardType → TextInputType?
结束框展示提示
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startHintText → String
结束输入内容
final
startInput → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited